EnergyModel

Struct EnergyModel 

pub struct EnergyModel {
    pub perf_doms: BTreeMap<usize, Arc<PerfDomain>>,
    pub eq_perf_doms: BTreeMap<usize, Arc<EqPerfDomain>>,
}

Fields

perf_doms: BTreeMap<usize, Arc<PerfDomain>>

Performance domains indexed by domain id

eq_perf_doms: BTreeMap<usize, Arc<EqPerfDomain>>

Equivalence performance domains indexed by equivalence domain id

Implementations

Source

impl EnergyModel

pub fn has_energy_model() -> bool

pub fn new() -> Result<EnergyModel>

Build a complete EnergyModel

fn group_perf_doms( perf_doms: &BTreeMap<usize, Arc<PerfDomain>>, ) -> BTreeMap<usize, Arc<EqPerfDomain>>

Group performance domains sharing an identical performance table into equivalence performance domains. Since @perf_doms is visited in ascending domain id order, both the members of an equivalence performance domain and the equivalence performance domains themselves are ordered by performance domain id.

pub fn get_pd_by_cpu_id(&self, cpu_id: usize) -> Option<&PerfDomain>

pub fn perf_total(&self) -> usize